@@ -181,6 +181,12 @@ class MySQL:
         self._cursor.execute(statement)
         self._printer('\tMySQL table ' + str(table) + ' successfully truncated')
 
+    def truncate_database(self):
+        """Drop all tables in a database."""
+        # Loop through each table and execute a drop command
+        return [self.drop_table(table) for table in
+                tqdm(self.tables, total=len(self.tables), desc='Truncating database')]
+
     # def create_table(self, table, data, headers=None):
     #     """Generate and execute a create table query by parsing a 2D dataset"""
     #     # TODO: Fix
@@ -202,20 +208,25 @@ class MySQL:
     #     self._printer(statement)
 
     def drop_table(self, table):
-        """Drop a table from the database."""
+        """Drop a table from a database."""
         self._cursor.execute('DROP TABLE ' + table)
         self._commit()
+        return table
 
     def drop_empty_tables(self):
         """Drop all empty tables in a database."""
-        # Count number of rows
+        # Count number of rows in each table
         counts = self.count_rows_all()
+        drops = []
 
         # Loop through each table key and validate that rows count is not 0
         for table, count in counts.items():
             if count < 1:
                 # Drop table if it contains no rows
                 self.drop_table(table)
+                self._printer('Dropped table', table)
+                drops.append(table)
+        return drops
 
     def execute_sql_script(self, sql_script):
         """Execute a sql file one command at a time."""
@@ -248,16 +259,17 @@ class MySQL:
         self._printer(success, 'total successful commands')
 
         # Dump failed commands to text file
-        if len(fails) < 1:
+        if len(fails) > 1:
             # Re-add semi-colon separator
             fails = [com + ';' for com in fails]
             self._printer(len(fails), 'total failed commands')
 
             # Dump failed commands to text file in the same directory as the script
-            txt_file = os.path.join(os.path.dirname(sql_script), 'sql fails.txt')
+            txt_file = os.path.join(os.path.dirname(sql_script),
+                                    str(os.path.basename(sql_script).rsplit('.')[0]) + '_fails.txt')
+            self._printer('Fail commands dumped to', txt_file)
             with open(txt_file, 'w') as txt:
                 txt.writelines(fails)
-            self._printer('Fail commands dumped to', txt_file)
 
     def get_schema(self, table, with_headers=False):
         """Retrieve the database schema for a particular table."""
